This is a copy of the py2neo package to restore the version history that got deleted.
It's not possible to re-upload a deleted version of a package to PyPI.
So if you rely on, for example, `py2neo ~= 4.1.0` in your project, you can simply switch to `py2neo-archive ~= 4.1.0`.
If your project works with py2neo 2021.2.3 or above, you can keep using `py2neo` as usual.

Note that this project will not get any updates past version 2021.2.3.

[![Build Status](https://travis-ci.org/nigelsmall/py2neo.svg?branch=release%2F2.0)](https://travis-ci.org/nigelsmall/py2neo)

Py2neo 2.0
==========

Py2neo is a client library and comprehensive toolkit for working with Neo4j from within Python
applications and from the command line. The core library has no external dependencies and has been
carefully designed to be easy and intuitive to use.


Requirements
------------

- Python 2.7, 3.3 or 3.4
- Neo4j 1.8, 1.9, 2.0 or 2.1 (latest point release of each version is recommended)


Installation
------------

To install, run the following::

    $ pip install py2neo


For more information, read through the [full introduction](http://py2neo.org/2.0/intro.html).

To get in touch, contact me via [email](mailto:nigel@py2neo.org) or on
[Twitter](https://twitter.com/neonige).

For the previous stable release, check out the [release/1.6.4 branch](https://github.com/nigelsmall/py2neo/tree/release/1.6.4).
